package
Version:
v0.0.0-...-3e0e934
Opens a new window with list of versions in this module.
Published: Jun 28, 2026
License: Apache-2.0, BSD-2-Clause
Opens a new window with license information.
Imports: 16
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BackupFilePair struct {
Locker func(func())
Source string
TargetDir string
}
type Config struct {
BackupPeriod string `toml:"backup_period"`
RootPath string `toml:"root_path"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.